@@ -1,10 +1,10 @@
 
 !- Version fortran 90
-!      
-      
-      module type	
-       
-      interface verif1    
+!
+
+      module type
+
+      interface verif1
       subroutine marq98j(k0,b,m,ni,v,rl,ier,istop,effet,ca,cb,dd,fctnames)
          integer,intent(in) :: m,effet
          integer,intent(inout)::ni,ier,istop
@@ -15,64 +15,64 @@
 	 double precision,intent(out)::ca,cb,dd
 	 external::fctnames
 	 double precision::fctnames
-	  
-      end subroutine marq98j    
-        
+
+      end subroutine marq98j
+
       subroutine derivaj(b,m,v,rl,k0,fctnames)
         integer,intent(in)::m
 	double precision,dimension(2)::k0
         double precision,intent(inout)::rl
         double precision,dimension(m),intent(in)::b
-        double precision,dimension((m*(m+3)/2)),intent(out)::v  
-	double precision,external::fctnames    
+        double precision,dimension((m*(m+3)/2)),intent(out)::v
+	double precision,external::fctnames
       end subroutine derivaj
-      
+
       subroutine searpasj(vw,step,b,bh,m,delta,fim,k0,fctnames)
-        integer,intent(in)::m      
+        integer,intent(in)::m
 	double precision,dimension(2)::k0
         double precision,dimension(m),intent(in)::b
         double precision,dimension(m),intent(inout)::bh,delta
         double precision,intent(inout)::vw,fim,step
-	double precision,external::fctnames       
+	double precision,external::fctnames
       end subroutine searpasj
-      
+
       subroutine dmfsdj(a,n,eps,ier)
         integer,intent(in)::n
         integer,intent(inout)::ier
         double precision,intent(inout)::eps 
-        double precision,dimension(n*(n+1)/2),intent(inout)::A      
+        double precision,dimension(n*(n+1)/2),intent(inout)::A
       end subroutine dmfsdj
-   
+
       subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames)
-        integer,intent(in)::m  
+        integer,intent(in)::m
 	double precision,dimension(2)::k0
 	double precision,intent(in)::vw
-        double precision,dimension(m),intent(in)::b,delta  
-        double precision,dimension(m),intent(out)::bk 
-        double precision,intent(out)::fi  
+        double precision,dimension(m),intent(in)::b,delta
+        double precision,dimension(m),intent(out)::bk
+        double precision,intent(out)::fi
 	double precision,external::fctnames
       end subroutine valfpaj
-      
+
       subroutine dmaxt(maxt,delta,m)
         integer,intent(in)::m
         double precision,dimension(m),intent(in)::delta 
         double precision,intent(out)::maxt
-      end subroutine dmaxt               	                 
-      end interface verif1  
+      end subroutine dmaxt
+      end interface verif1
 
       interface verif2
       subroutine dsinvj(A,N,EPS,IER)
         integer,intent(in)::n
         integer,intent(inout)::ier
-        double precision,intent(inout)::eps        
-        double precision,dimension(n*(n+1)/2),intent(inout)::A  
-      end subroutine dsinvj 
-      
+        double precision,intent(inout)::eps
+        double precision,dimension(n*(n+1)/2),intent(inout)::A
+      end subroutine dsinvj
+
       subroutine dcholej(a,k,nq,idpos)
       integer,intent(in)::k,nq
       integer,intent(inout)::idpos
-      double precision,dimension(k*(k+3)/2),intent(inout)::a      
-      end subroutine dcholej     
+      double precision,dimension(k*(k+3)/2),intent(inout)::a
+      end subroutine dcholej
       end interface verif2
 
       end module type
@@ -86,11 +86,11 @@
       module optim
 
       implicit none
-! -Interface permettant la verification des type des arguments      
-      interface verif1     
+! -Interface permettant la verification des type des arguments
+      interface verif1
         module procedure marq98j,derivaj,searpasj,dmfsdj,valfpaj
       end interface verif1
-      
+
       interface verif2
         module procedure dsinvj,dcholej,dmaxt
       end interface verif2
@@ -118,7 +118,7 @@
 
 !add additive
 	use additiv,only:correl
-      
+
 	IMPLICIT NONE
 !   variables globales
 	integer,intent(in) :: m,effet
@@ -129,7 +129,7 @@
 	double precision,intent(out)::ca,cb,dd
 	double precision,dimension(2)::k0
         double precision,dimension(2)::zero
-!   variables locales            
+!   variables locales
 	integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
 	double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
 	double precision,dimension(m)::delta,b1,bh
@@ -222,11 +222,11 @@
 		
 		ncount=0
 		ga=0.01d0
-		
+
  400    do i=1,nfmax+m
            fu(i)=v(i)
         end do
-	
+
 		do i=1,m
 			ii=i*(i+1)/2
 			if (v(ii).ne.0) then
@@ -237,7 +237,7 @@
 		end do
 		
 		call dcholej(fu,m,nql,idpos)
-	
+
 		if (idpos.ne.0) then
 			ncount=ncount+1
 			if (ncount.le.3.or.ga.ge.1.d0) then
@@ -246,7 +246,7 @@
 				ga=ga*dm
 				if (ga.gt.1.d0) ga=1.d0
 			endif
-	
+
 			goto 400
 
 		else
@@ -287,7 +287,7 @@
 			istop=4
 			goto 110
 		end if
-            
+
 		do i=1,m
 			delta(i)=vw*delta(i)
 		end do
@@ -300,6 +300,7 @@
 			ca=ca+delta(i)*delta(i)
 		end do
         !write(6,*) 'ca =',ca,' cb =',cb,' dd =',dd
+
 		do i=1,m
 			b(i)=b(i)+delta(i)
 		end do
@@ -309,11 +310,11 @@
 			istop=2
 !            write(6,*) 'maximum number of iteration reached'
 			goto 110
-		end if	 
-	End do Main     
-	  
+		end if
+	End do Main
+
 	v=0.D0
-		
+	
 	v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
 	
 	istop=1
@@ -332,14 +333,14 @@
 	end do
 !---- Choix du model
 
-	select case(model) 
-		case(1)  
+	select case(model)
+		case(1)
 			m1=m-nva-effet-indic_alpha !joint
 		case(2)
 			m1=m-nva-effet*2 !additive	
 		case(3)
 			m1=m-nva-effet !nested
-		case(4)	
+		case(4)
 			m1=m-nva-effet !shared
 	end select
 
@@ -356,7 +357,7 @@
 
 	ep=10.d-10
 	call dsinvJ(v1,m1,ep,ier)
-	
+
 	if (ier.eq.-1) then
 !         write(*,*)   'echec inversion matrice information'
 		istop=3
@@ -397,7 +398,7 @@
 ! fin ajout amadou
 	endif
 
-	
+
 	ep=10.d-10
 	call derivaJ(b,m,vnonpen,rl,zero,fctnames)
 	
@@ -458,7 +459,7 @@
 	integer ::i0,m1,ll,i,k,j,iun
 	double precision::fctnames,thn,th,z,vl,th2,vaux
 	external::fctnames
-      	
+
 	select case(model)
 	case(1)
 		th=1.d-3 !joint
@@ -478,16 +479,17 @@
 
 	rl=fctnames(b,m,iun,z,iun,z,k0)
 
-        if(rl.eq.-1.d9) then
-            rl=-1.d9
-            goto 123
-        end if	
+	if(rl.eq.-1.d9) then
+		rl=-1.d9
+		goto 123
+	end if
+
 	do i=1,m
 		fcith(i)=fctnames(b,m,i,th,i0,z,k0)
-                if(fcith(i).eq.-1.d9) then
-                    rl=-1.d9
-                    goto 123
-                end if
+		if(fcith(i).eq.-1.d9) then
+			rl=-1.d9
+			goto 123
+		end if
 	end do
 
 	k=0
@@ -523,22 +525,22 @@
 !  MINIMISATION UNIDIMENSIONNELLE
 !
       implicit none
-       
-      integer,intent(in)::m      
+
+      integer,intent(in)::m
       double precision,dimension(m),intent(in)::b
       double precision,intent(inout)::vw
-      double precision,dimension(m),intent(inout)::bh,delta      
-      double precision,intent(inout)::fim,step   
-      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3    
+      double precision,dimension(m),intent(inout)::bh,delta
+      double precision,intent(inout)::fim,step
+      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3
       double precision,dimension(2)::k0
       double precision::fctnames
-      external::fctnames     
-      integer::i 
+      external::fctnames
+      integer::i
 
        vlw1=dlog(vw)
        vlw2=vlw1+step
        call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames)
-       call valfpaj(vlw2,fi2,b,bh,m,delta,k0,fctnames)       
+       call valfpaj(vlw2,fi2,b,bh,m,delta,k0,fctnames)
 
        if(fi2.ge.fi1) then
 	  vlw3=vlw2
@@ -548,7 +550,7 @@
 	  step=-step
 
           vlw1=vlw2+step
-          call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames)   
+          call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames)
           if(fi1.gt.fi2) goto 50
        else 
           vlw=vlw1
@@ -1004,7 +1006,516 @@
 		
 	return
 	end subroutine dmaxt
+
+!----------- add for multiv Yassin
+
+	subroutine marq98(k0,b,m,ni,v,rl,ier,istop,effet,ca,cb,dd,fctnames)
+
+!
+!  fu = matrice des derivees secondes et premieres
+!
+!  istop: raison de l'arret
+!  1: critere d'arret satisfait (prm=ca, vraisblce=cb, derivee=dd)
+!  2: nb max d'iterations atteints
+!  4: Erreur
+	use residusMmultiv,only:indg
+	use parametersmultiv
+	use comonmultiv,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
+	nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
+	PEN_deri,I_hess,H_hess,Hspl_hess,hess,indic_ALPHA,typeof,indic_eta,vvv
+
+!add additive
+	use additiv,only:correl
+      
+	IMPLICIT NONE
+!   variables globales 
+	integer,intent(in) :: m,effet
+	integer,intent(inout)::ni,ier,istop
+	double precision,dimension(m*(m+3)/2),intent(out)::v
+	double precision,intent(out)::rl
+	double precision,dimension(m),intent(inout)::b
+	double precision,intent(out)::ca,cb,dd
+	double precision,dimension(3)::k0
+        double precision,dimension(3)::zero
+!   variables locales            
+	integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
+	double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
+	double precision,dimension(m)::delta,b1,bh
+	double precision::da,dm,ga,tr
+	double precision::GHG,step,eps,vw,fi,maxt, &
+	z,rl1,th,ep
+	external::fctnames
+	double precision::fctnames
+!---------- ajout
+	integer::kkk
+
+	zero=0.d0     
+	id=0
+	jd=0
+	z=0.d0
+	th=1.d-5
+	eps=1.d-7!1.d-6
+	nfmax=m*(m+1)/2  	  
+	ca=epsa+1.d0
+	cb=epsb+1.d0
+	rl1=-1.d+10    
+	ni=0
+	istop=0
+	da=0.01d0
+	dm=5.d0
+	nql=1
+	m1=m*(m+1)/2
+	ep=1.d-20
+	Main:Do 
+
+        call deriva(b,m,v,rl,k0,fctnames)   
+
+        rl1=rl
+	if(rl.eq.-1.D9) then
+		istop=4
+		goto 110
+	end if
+! 	write(*,*)'parameters***',b
+!	write(*,*)'Optim iteration***',ni,'vrais',rl  
+	   
+        dd = 0.d0    
+	 
+        fu=0.D0
 	
+	do i=1,m
+		do j=i,m
+			ij=(j-1)*j/2+i
+			fu(ij)=v(ij)
+		end do
+	end do
+	
+        call dsinvj(fu,m,ep,ier)  
+	
+	if (ier.eq.-1) then
+		dd=epsd+1.d0
+	else
+		GHG = 0.d0
+		do i=1,m
+			do j=1,m
+				if(j.ge.i) then
+					ij=(j-1)*j/2+i
+				else
+					ij=(i-1)*i/2+j
+				end if
+				GHG = GHG + v(m1+i)*fu(ij)*V(m1+j)
+			end do
+		end do
+		dd=GHG/dble(m)
+	end if
+	if(ca.lt.epsa.and.cb.lt.epsb.and.dd.lt.epsd) exit main
+
+		tr=0.d0
+		do i=1,m
+			ii=i*(i+1)/2
+			tr=tr+dabs(v(ii))
+		end do
+		tr=tr/dble(m)
+		
+		ncount=0
+		ga=0.01d0
+		
+ 400    do i=1,nfmax+m
+           fu(i)=v(i)
+        end do
+	
+		do i=1,m
+			ii=i*(i+1)/2
+			if (v(ii).ne.0) then
+				fu(ii)=v(ii)+da*((1.d0-ga)*dabs(v(ii))+ga*tr)
+			else
+				fu(ii)=da*ga*tr
+			endif
+		end do
+		
+		call dcholej(fu,m,nql,idpos)
+		if (idpos.ne.0) then
+			ncount=ncount+1
+			if (ncount.le.3.or.ga.ge.1.d0) then
+				da=da*dm
+			else
+				ga=ga*dm
+				if (ga.gt.1.d0) ga=1.d0
+			endif
+	
+			goto 400
+
+		else
+			do i=1,m
+				delta(i)=fu(nfmax+i)
+				b1(i)=b(i)+delta(i)
+			end do
+			rl=fctnames(b1,m,id,z,jd,z,k0)
+			if(rl.eq.-1.D9) then
+				istop=4
+				goto 110
+			end if
+			if (rl1.lt.rl) then
+				if(da.lt.eps) then
+					da=eps
+				else
+					da=da/(dm+2.d0)
+				endif
+				goto 800
+			endif
+		endif
+!      write(6,*) 'loglikelihood not improved '
+		call dmaxt(maxt,delta,m)
+
+		if(maxt.eq.0.D0) then
+			vw=th
+		else
+			!call dmaxt(maxt,delta,m)
+			vw=th/maxt
+			
+		endif
+		step=dlog(1.5d0)
+!      write(*,*) 'searpas'
+		call searpas(vw,step,b,bh,m,delta,fi,k0,fctnames)
+		rl=-fi
+		if(rl.eq.-1.D9) then
+			istop=4
+			goto 110
+		end if
+            
+		do i=1,m
+			delta(i)=vw*delta(i)
+		end do
+		da=(dm-3.d0)*da
+
+ 800     cb=dabs(rl1-rl)
+		ca=0.d0
+		do i=1,m
+			ca=ca+delta(i)*delta(i)
+		end do
+!         write(6,*) 'ca =',ca,' cb =',cb,' dd =',dd
+		do i=1,m
+			b(i)=b(i)+delta(i)
+		end do
+	
+		ni=ni+1
+
+		if (ni.ge.maxiter) then
+			istop=2
+ !           write(6,*) 'maximum number of iteration reached'
+			goto 110
+		end if	 
+	End do Main
+
+	v=0.D0
+		
+	v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
+	
+	istop=1
+	
+!================ pour les bandes de confiance
+!==== on ne retient que les para des splines
+
+	call deriva(b,m,v,rl,k0,fctnames)
+	if(rl.eq.-1.D9) then
+		istop=4
+		goto 110
+	end if
+
+	do i=1,(m*(m+3)/2)
+		v1(i)=0.d0
+	end do
+!---- Choix du model
+
+	select case(model) 
+		case(1)  
+			m1=m-nva-effet-indic_alpha !joint
+		case(2)
+			m1=m-nva-effet*2 !additive	
+		case(3)
+			m1=m-nva-effet !nested
+		case(4)	
+			m1=m-nva-effet !shared
+	end select
+
+	kkk=m1*(m1+1)/2
+	
+	do i=1,m1
+		kkk=kkk+1
+		do j=i,m1
+			k = (((j-1)*j)/2) +i
+			v1(k)=v(k)/(4.d0*b(i)*b(j))
+		end do
+		v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
+	end do 
+
+	ep=10.d-10
+	call dsinvJ(v1,m1,ep,ier)
+	
+	if (ier.eq.-1) then
+!         write(*,*)   'echec inversion matrice information'
+		istop=3
+	endif
+
+
+
+	do i=1,m1
+		do j=i,m1
+			hess(i,j)=v1((j-1)*j/2+i)
+		end do
+	end do
+
+	do i=2,m1
+		do j=1,i-1
+			hess(i,j)=hess(j,i)
+		end do
+	end do
+
+	
+	ep=10.d-10
+	call dsinvJ(v,m,ep,ier)
+	
+	if (ier.eq.-1) then
+		istop=3
+		
+!AD:
+!		call dsinvj(v1,m1,ep,ier)
+!		if (ier.eq.-1) then
+!             write(*,*)'echec inversion matrice information
+!     & prms fixes'
+!			istop=31
+!		else
+!			DO k=1,m1*(m1+1)/2
+!				v(k)=v1(k)
+!			END DO
+!		end if	
+! fin ajout amadou
+	endif
+
+	
+	ep=10.d-10
+	call deriva(b,m,vnonpen,rl,zero,fctnames)
+	
+	do i=1,m
+		do j=i,m
+			I_hess(i,j)=vnonpen((j-1)*j/2+i)
+		end do
+	end do
+   
+	do i=2,m
+		do j=1,i-1
+			I_hess(i,j)=I_hess(j,i)
+		end do
+	end do
+
+!========================================================
+
+!   H_hess est moins la hessienne inverse sur la vraisemblance penalisee
+	do i=1,m
+		do j=i,m
+			H_hess(i,j)=v((j-1)*j/2+i)
+		end do
+	end do
+!       write(*,*) 'H_hess(16,16) fin marq',H_hess(16,16),m,((j-1)*j/2+i)
+
+	do i=2,m
+		do j=1,i-1
+			H_hess(i,j)=H_hess(j,i)
+		end do
+	end do      
+
+ !AD:
+	if (typeof .ne. 0) then
+		do i=1,m*(m+1)/2
+			vvv(i)=v(i)
+		end do
+	end if
+
+ 110   continue
+
+       return    
+
+       end subroutine marq98
+
+
+	subroutine deriva(b,m,v,rl,k0,fctnames)
+	use comonmultiv,only:model
+	implicit none
+	
+	integer,intent(in)::m
+	double precision,intent(inout)::rl
+	double precision,dimension(3)::k0
+	double precision,dimension(m),intent(in)::b
+	double precision,dimension((m*(m+3)/2)),intent(out)::v     
+	double precision,dimension(m)::fcith
+	integer ::i0,m1,ll,i,k,j,iun
+	double precision::fctnames,thn,th,z,vl,th2,vaux  
+	external::fctnames
+      	
+	select case(model)
+	case(1)
+		th=1.d-3 !joint	
+	case(2)
+		th=5.d-3 !additive
+	case(3)
+		th=1.d-5 !nested		
+	case(4)
+		th=1.d-5 !shared
+	end select
+	
+	thn=-th
+	th2=th*th
+	z=0.d0
+	i0=0
+	iun =1
+
+	rl=fctnames(b,m,iun,z,iun,z,k0)
+        if(rl.eq.-1.d9) then
+            rl=-1.d9
+            goto 123
+        end if	
+	do i=1,m
+		fcith(i)=fctnames(b,m,i,th,i0,z,k0)
+                if(fcith(i).eq.-1.d9) then
+                    rl=-1.d9
+                    goto 123
+                end if
+	end do
+
+	k=0
+	m1=m*(m+1)/2
+	ll=m1
+	
+	do i=1,m
+		ll=ll+1
+		vaux=fctnames(b,m,i,thn,i0,z,k0)
+                if(vaux.eq.-1.d9) then
+                    rl=-1.d9
+                    goto 123
+                end if	
+		vl=(fcith(i)-vaux)/(2.d0*th)
+		v(ll)=vl
+		do j=1,i
+			k=k+1
+			v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
+		end do
+	end do
+      
+123   continue	
+	return
+	
+	end subroutine deriva
+
+
+      subroutine searpas(vw,step,b,bh,m,delta,fim,k0,fctnames)
+!
+!  MINIMISATION UNIDIMENSIONNELLE
+!
+      implicit none
+       
+      integer,intent(in)::m      
+      double precision,dimension(m),intent(in)::b
+      double precision,intent(inout)::vw
+      double precision,dimension(m),intent(inout)::bh,delta      
+      double precision,intent(inout)::fim,step   
+      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3    
+      double precision,dimension(3)::k0
+      double precision::fctnames
+      external::fctnames
+      integer::i 
+
+       vlw1=dlog(vw)
+       vlw2=vlw1+step
+       call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
+       call valfpa(vlw2,fi2,b,bh,m,delta,k0,fctnames)       
+
+       if(fi2.ge.fi1) then
+	  vlw3=vlw2
+	  vlw2=vlw1
+	  fi3=fi2
+	  fi2=fi1
+	  step=-step
+
+          vlw1=vlw2+step
+          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)   
+          if(fi1.gt.fi2) goto 50
+       else 
+          vlw=vlw1
+          vlw1=vlw2
+          vlw2=vlw
+          fim=fi1
+          fi1=fi2
+          fi2=fim
+       end if
+
+       do i=1,40
+          vlw3=vlw2
+          vlw2=vlw1
+          fi3=fi2
+          fi2=fi1
+
+          vlw1=vlw2+step
+          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
+          if(fi1.gt.fi2) goto 50
+          if(fi1.eq.fi2) then
+             fim=fi2
+             vm=vlw2 
+             goto 100
+          end if
+       end do
+!
+!  PHASE 2 APPROXIMATION PAR QUADRIQUE
+!
+50     continue
+!
+!  CALCUL MINIMUM QUADRIQUE
+!
+      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
+      call valfpa(vm,fim,b,bh,m,delta,k0,fctnames)	
+      if(fim.le.fi2) goto 100
+      vm=vlw2
+      fim=fi2
+100   continue
+      vw=dexp(vm)
+      
+      return
+
+      end subroutine searpas
+
+
+	subroutine valfpa(vw,fi,b,bk,m,delta,k0,fctnames)
+	
+	implicit none
+	
+	integer,intent(in)::m  
+	double precision,dimension(m),intent(in)::b,delta  
+	double precision,dimension(m),intent(out)::bk 
+	double precision,intent(out)::fi 
+	double precision::vw,fctnames,z	
+	double precision,dimension(3)::k0
+	integer::i0,i
+	external::fctnames
+	
+	z=0.d0
+	i0=1
+	do i=1,m
+	bk(i)=b(i)+dexp(vw)*delta(i)
+	end do
+	fi=-fctnames(bk,m,i0,z,i0,z,k0)
+	if(fi.eq.-1.D9) then
+		goto 1
+	end if
+1       continue
+	return
+	
+	end subroutine valfpa
+
+
+
+
+
+
+
+
 	end module optim
 
 		
